@@ -30,7 +30,8 @@
   } while (0)
 
 /* types */
-typedef enum {
+typedef enum
+{
   CTX_STOP_NONE,
   CTX_STOP_STEP,
   CTX_STOP_BREAKPOINT,
@@ -54,7 +55,8 @@ typedef struct
   VALUE backtrace; /* [[loc, self, klass, binding], ...] */
 } debug_context_t;
 
-typedef enum {
+typedef enum
+{
   LOCATION,
   SELF,
   CLASS,
