@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
-require "byebug/command"
-require "byebug/helpers/eval"
+require_relative "../command"
+require_relative "../helpers/eval"
 
 module Byebug
   #
