@@ -1,4 +1,6 @@
-require 'byebug/helpers/toggle'
+# frozen_string_literal: true
+
+require_relative "../../helpers/toggle"
 
 module Byebug
   #
@@ -8,23 +10,17 @@ module Byebug
     #
     # Enables all or specific displays
     #
-    class DisplaySubcommand < Command
+    class DisplayCommand < Command
       include Helpers::ToggleHelper
 
-      def regexp
+      self.allow_in_post_mortem = true
+
+      def self.regexp
         /^\s* d(?:isplay)? (?:\s+ (.+))? \s*$/x
       end
 
-      def execute
-        enable_disable_display('disable', @match[1])
-      end
-
-      def short_description
-        'Disables expressions to be displayed when program stops.'
-      end
-
-      def description
-        <<-EOD
+      def self.description
+        <<-DESCRIPTION
           dis[able] d[isplay][ <id1> <id2> .. <idn>]
 
           #{short_description}
@@ -32,7 +28,15 @@ module Byebug
           Arguments are the code numbers of the expressions to disable. Do "info
           display" to see the current list of code numbers. If no arguments are
           specified, all displays are disabled.
-        EOD
+        DESCRIPTION
+      end
+
+      def self.short_description
+        "Disables expressions to be displayed when program stops."
+      end
+
+      def execute
+        enable_disable_display("disable", @match[1])
       end
     end
   end
