@@ -35,11 +35,7 @@ module Byebug
     def test_subdebugger_stops_at_correct_point_when_invoked_from_breakpoint
       enter "break #{example_class}.a", "debug #{example_class}.a"
 
-      if RUBY_VERSION >= "2.5.0"
-        debug_code(program) { assert_equal 7, frame.line }
-      else
-        debug_code(program) { assert_equal 6, frame.line }
-      end
+      debug_code(program) { assert_equal 7, frame.line }
     end
 
     def test_subdebugger_goes_back_to_previous_debugger_after_continue
